@@ -1,6 +1,6 @@
 import logging
 import os
-from typing import Optional
+from typing import Any, Optional
 
 import pystac
 from pystac.extensions.eo import EOExtension
@@ -10,8 +10,7 @@ from stactools.core.io import ReadHrefModifier
 
 from . import Format
 from .bands import image_asset_from_href
-from .constants import (SENTINEL_CONSTELLATION, SENTINEL_LICENSE,
-                        SENTINEL_PROVIDER)
+from .constants import SENTINEL_CONSTELLATION, SENTINEL_LICENSE, SENTINEL_PROVIDER
 from .metadata_links import MetadataLinks
 from .product_metadata import ProductMetadata, get_shape
 from .properties import fill_sar_properties, fill_sat_properties
@@ -23,6 +22,7 @@ def create_item(
     granule_href: str,
     read_href_modifier: Optional[ReadHrefModifier] = None,
     archive_format: Format = Format.SAFE,
+    **kwargs: Any,
 ) -> pystac.Item:
     """Create a STC Item from a Sentinel-1 GRD scene.
 
@@ -40,7 +40,12 @@ def create_item(
         pystac.Item: An item representing the Sentinel-1 GRD scene.
     """
 
-    metalinks = MetadataLinks(granule_href, read_href_modifier, archive_format)
+    metalinks = MetadataLinks(
+        granule_href,
+        read_href_modifier,
+        archive_format,
+        **kwargs,
+    )
 
     product_metadata = ProductMetadata(
         metalinks.product_metadata_href,
@@ -76,10 +81,8 @@ def create_item(
     item.common_metadata.constellation = SENTINEL_CONSTELLATION
 
     # s1 properties
-    shape = get_shape(metalinks, read_href_modifier)
-    item.properties.update({
-        **product_metadata.metadata_dict, "s1:shape": shape
-    })
+    shape = get_shape(metalinks, read_href_modifier, **kwargs)
+    item.properties.update({**product_metadata.metadata_dict, "s1:shape": shape})
 
     # Add assets to item
     item.add_asset(*metalinks.create_manifest_asset())
@@ -98,19 +101,24 @@ def create_item(
 
     # Thumbnail
     if metalinks.thumbnail_href is not None:
-        desc = "An averaged, decimated preview image in PNG format. Single polarisation " \
-               "products are represented with a grey scale image. Dual polarisation products " \
-               "are represented by a single composite colour image in RGB with the red channel " \
-               "(R) representing the  co-polarisation VV or HH), the green channel (G) " \
-               "represents the cross-polarisation (VH or HV) and the blue channel (B) " \
-               "represents the ratio of the cross an co-polarisations."
+        desc = (
+            "An averaged, decimated preview image in PNG format. Single polarisation "
+            "products are represented with a grey scale image. Dual polarisation products "
+            "are represented by a single composite colour image in RGB with the red channel "
+            "(R) representing the  co-polarisation VV or HH), the green channel (G) "
+            "represents the cross-polarisation (VH or HV) and the blue channel (B) "
+            "represents the ratio of the cross an co-polarisations."
+        )
         item.add_asset(
             "thumbnail",
-            pystac.Asset(href=metalinks.thumbnail_href,
-                         media_type=pystac.MediaType.PNG,
-                         roles=["thumbnail"],
-                         title="Preview Image",
-                         description=desc))
+            pystac.Asset(
+                href=metalinks.thumbnail_href,
+                media_type=pystac.MediaType.PNG,
+                roles=["thumbnail"],
+                title="Preview Image",
+                description=desc,
+            ),
+        )
 
     images_media_type = None
     if archive_format == Format.SAFE:
@@ -118,12 +126,16 @@ def create_item(
     elif archive_format == Format.COG:
         images_media_type = pystac.MediaType.COG
 
-    image_assets = dict([
-        image_asset_from_href(os.path.join(granule_href, image_path),
-                              item,
-                              media_type=images_media_type)
-        for image_path in product_metadata.image_paths
-    ])
+    image_assets = dict(
+        [
+            image_asset_from_href(
+                os.path.join(granule_href, image_path),
+                item,
+                media_type=images_media_type,
+            )
+            for image_path in product_metadata.image_paths
+        ]
+    )
 
     for key, asset in image_assets.items():
         assert key not in item.assets
